"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Alert = Alert;
exports.AlertType = exports.AlertService = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

var _react = _interopRequireWildcard(require("react"));

var _reactRouterDom = require("react-router-dom");

var _propTypes = _interopRequireDefault(require("prop-types"));

var _rxjs = require("rxjs");

var _operators = require("rxjs/operators");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const alertSubject = new _rxjs.Subject();
const defaultId = 'default-alert';
const propTypes = {
  id: _propTypes.default.string,
  fade: _propTypes.default.bool
};
const defaultProps = {
  id: 'default-alert',
  fade: true
};

function Alert(_ref) {
  let {
    id,
    fade
  } = _ref;
  const history = (0, _reactRouterDom.useHistory)();
  const [alerts, setAlerts] = (0, _react.useState)([]);
  (0, _react.useEffect)(() => {
    // subscribe to new alert notifications
    const subscription = AlertService.onAlert(id).subscribe(alert => {
      // clear alerts when an empty alert is received
      if (!alert.message) {
        setAlerts(alerts => {
          // filter out alerts without 'keepAfterRouteChange' flag
          const filteredAlerts = alerts.filter(x => x.keepAfterRouteChange); // remove 'keepAfterRouteChange' flag on the rest

          filteredAlerts.forEach(x => delete x.keepAfterRouteChange);
          return filteredAlerts;
        });
      } else {
        // add alert to array
        setAlerts(alerts => [...alerts, alert]); // auto close alert if required

        if (alert.autoClose) {
          setTimeout(() => removeAlert(alert), 3000);
        }
      }
    }); // clear alerts on location change

    const historyUnlisten = history.listen(() => {
      AlertService.clear(id);
    }); // clean up function that runs when the component unmounts

    return () => {
      // unsubscribe & unlisten to avoid memory leaks
      subscription.unsubscribe();
      historyUnlisten();
    };
  });

  function removeAlert(alert) {
    if (fade) {
      // fade out alert
      const alertWithFade = _objectSpread(_objectSpread({}, alert), {}, {
        fade: true
      });

      setAlerts(alerts => alerts.map(x => x === alert ? alertWithFade : x)); // remove alert after faded out

      setTimeout(() => {
        setAlerts(alerts => alerts.filter(x => x !== alertWithFade));
      }, 250);
    } else {
      // remove alert
      setAlerts(alerts => alerts.filter(x => x !== alert));
    }
  }

  function cssClasses(alert) {
    if (!alert) return;
    const classes = ['alert', 'alert-dismissible'];
    const alertTypeClass = {
      [AlertType.Success]: 'alert-success',
      [AlertType.Error]: 'alert-danger',
      [AlertType.Info]: 'alert-info',
      [AlertType.Warning]: 'alert-warning'
    };
    classes.push(alertTypeClass[alert.type]);

    if (alert.fade) {
      classes.push('fade');
    }

    return classes.join(' ');
  }

  if (!alerts.length) return null;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: "container"
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: "m-3"
  }, alerts.map((alert, index) => /*#__PURE__*/_react.default.createElement("div", {
    key: index,
    className: cssClasses(alert),
    role: "alert"
  }, /*#__PURE__*/_react.default.createElement("span", {
    dangerouslySetInnerHTML: {
      __html: alert.message
    }
  }), /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: "btn-close",
    "aria-label": "Close",
    onClick: () => removeAlert(alert)
  })))));
}

const AlertService = {
  onAlert,
  success,
  error,
  info,
  warn,
  alert,
  clear
};
exports.AlertService = AlertService;
const AlertType = {
  Success: 'Success',
  Error: 'Error',
  Info: 'Info',
  Warning: 'Warning'
}; // enable subscribing to alerts observable

exports.AlertType = AlertType;

function onAlert() {
  let id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultId;
  return alertSubject.asObservable().pipe((0, _operators.filter)(x => x && x.id === id));
} // convenience methods


function success(message, options) {
  showAlert(_objectSpread(_objectSpread({}, options), {}, {
    type: AlertType.Success,
    message
  }));
}

function error(message, options) {
  showAlert(_objectSpread(_objectSpread({}, options), {}, {
    type: AlertType.Error,
    message
  }));
}

function info(message, options) {
  showAlert(_objectSpread(_objectSpread({}, options), {}, {
    type: AlertType.Info,
    message
  }));
}

function warn(message, options) {
  showAlert(_objectSpread(_objectSpread({}, options), {}, {
    type: AlertType.Warning,
    message
  }));
} // core alert method


function showAlert(alert) {
  alert.id = alert.id || defaultId;
  alertSubject.next(alert);
} // clear alerts


function clear() {
  let id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultId;
  alertSubject.next({
    id
  });
}

Alert.propTypes = propTypes;
Alert.defaultProps = defaultProps;